from setuptools import setup, find_packages

setup(
    name="get_lunchbox",  # unikalna nazwa (PyPI nie pozwoli na 'textutils')
    version="1.1" , # Potem 1.2
    packages=find_packages(),
    install_requires=[],
    description="Useful tool for easy importing with aliases",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Carlos",
    author_email="karlos.santana13@gmail.com",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
)


import importlib
def get_lunchbox(*modules):
    class Box:
        pass

    box = Box()

    for mod in modules:
        if isinstance(mod, tuple):
            module_path = mod[0]
            alias = mod[1] if len(mod) > 1 else module_path.split(".")[-1]
        else:
            raise ValueError("Modules must be passed as tuples")

        try:
            module = importlib.import_module(module_path)
            setattr(box, alias, module)
        except ImportError as e:
            print(f"Could not import {module_path}: {e}")

    return box
class LazyBox:
    def __init__(self, modules):
        self._module_defs = modules
        self._loaded_modules = {}

    def __getattr__(self, name):
        if name in self._loaded_modules:
            return self._loaded_modules[name]

        for module_path, alias in self._module_defs:
            if alias == name:
                import importlib
                mod = importlib.import_module(module_path)
                self._loaded_modules[name] = mod
                return mod

        raise AttributeError(f"No module alias '{name}' found.")

def get_lazy_lunchbox(*modules):
    return LazyBox(modules)